@@ -51,6 +51,9 @@ else
     pip uninstall spyder-kernels -q -y
     pip uninstall python-lsp-server -q -y
     pip uninstall qdarkstyle -q -y
+
+    # Install jupyter-client 6 until we release spyder-kernels 2.1.1
+    pip install jupyter-client==6.1.12
 fi
 
 # Install subrepos in development mode
@@ -61,6 +64,11 @@ do
     popd
 done
 
+# Install boilerplate plugin
+pushd spyder/app/tests/spyder-boilerplate
+pip install --no-deps -q -e .
+popd
+
 # Install Spyder to test it as if it was properly installed
 # Note: `python setup.py egg_info` doesn't work here but it
 # does locally.
