@@ -30,7 +30,6 @@ import os.path as osp
 import shutil
 import signal
 import socket
-import glob
 import sys
 import threading
 import traceback
@@ -49,9 +48,9 @@ requirements.check_spyder_kernels()
 from qtpy.compat import from_qvariant
 from qtpy.QtCore import (QCoreApplication, Qt, QTimer, Signal, Slot,
                          qInstallMessageHandler)
-from qtpy.QtGui import QColor, QKeySequence
-from qtpy.QtWidgets import (QAction, QApplication, QMainWindow, QMenu,
-                            QMessageBox, QShortcut, QStyleFactory, QCheckBox)
+from qtpy.QtGui import QColor, QKeySequence, QIcon
+from qtpy.QtWidgets import (QApplication, QMainWindow, QMenu, QMessageBox,
+                            QShortcut, QStyleFactory)
 
 # Avoid a "Cannot mix incompatible Qt library" error on Windows platforms
 from qtpy import QtSvg  # analysis:ignore
@@ -71,7 +70,7 @@ from spyder import __version__
 from spyder import dependencies
 from spyder.app.utils import (
     create_application, create_splash_screen, create_window,
-    delete_lsp_log_files, qt_message_handler, set_links_color, setup_logging,
+    delete_debug_log_files, qt_message_handler, set_links_color, setup_logging,
     set_opengl_implementation)
 from spyder.api.plugin_registration.registry import PLUGIN_REGISTRY
 from spyder.config.base import (_, DEV, get_conf_path, get_debug_level,
@@ -153,7 +152,7 @@ class MainWindow(QMainWindow):
     sig_moved = Signal("QMoveEvent")
     sig_layout_setup_ready = Signal(object)  # Related to default layouts
 
-    # --- Plugin handling methods
+    # ---- Plugin handling methods
     # ------------------------------------------------------------------------
     def get_plugin(self, plugin_name, error=True):
         """
@@ -223,11 +222,6 @@ class MainWindow(QMainWindow):
         self.set_splash(_("Loading {}...").format(plugin.get_name()))
         logger.info("Loading {}...".format(plugin.NAME))
 
-        if plugin_name in [Plugins.Breakpoints,
-                           Plugins.Profiler,
-                           Plugins.Pylint]:
-            self.thirdparty_plugins.append(plugin)
-
         # Check plugin compatibility
         is_compatible, message = plugin.check_compatibility()
         plugin.is_compatible = is_compatible
@@ -241,7 +235,6 @@ class MainWindow(QMainWindow):
         plugin.sig_exception_occurred.connect(self.handle_exception)
         plugin.sig_free_memory_requested.connect(self.free_memory)
         plugin.sig_quit_requested.connect(self.close)
-        plugin.sig_restart_requested.connect(self.restart)
         plugin.sig_redirect_stdio_requested.connect(
             self.redirect_internalshell_stdio)
         plugin.sig_status_message_requested.connect(self.show_status_message)
@@ -548,6 +541,10 @@ class MainWindow(QMainWindow):
         # Enabling scaling for high dpi
         qapp.setAttribute(Qt.AA_UseHighDpiPixmaps)
 
+        # Set Windows app icon to use .ico file
+        if os.name == "nt":
+            qapp.setWindowIcon(ima.get_icon("windows_app_icon"))
+
         self.default_style = str(qapp.style().objectName())
 
         self.init_workdir = options.working_directory
@@ -704,9 +701,6 @@ class MainWindow(QMainWindow):
         self.last_focused_widget = None
         self.previous_focused_widget = None
 
-        # Keep track of dpi message
-        self.show_dpi_message = True
-
         # Server to open external files on a single instance
         # This is needed in order to handle socket creation problems.
         # See spyder-ide/spyder#4132.
@@ -739,7 +733,7 @@ class MainWindow(QMainWindow):
 
         logger.info("End of MainWindow constructor")
 
-    # --- Window setup
+    # ---- Window setup
     def _update_shortcuts_in_panes_menu(self, show=True):
         """
         Display the shortcut for the "Switch to plugin..." on the toggle view
@@ -916,15 +910,14 @@ class MainWindow(QMainWindow):
                     plugin_instance = PLUGIN_REGISTRY.register_plugin(
                         self, PluginClass, external=True)
 
-                    if not running_under_pytest():
-                        # These attributes come from spyder.app.find_plugins
-                        module = PluginClass._spyder_module_name
-                        package_name = PluginClass._spyder_package_name
-                        version = PluginClass._spyder_version
-                        description = plugin_instance.get_description()
-                        dependencies.add(module, package_name, description,
-                                         version, None,
-                                         kind=dependencies.PLUGIN)
+                    # These attributes come from spyder.app.find_plugins to
+                    # add plugins to the dependencies dialog
+                    module = PluginClass._spyder_module_name
+                    package_name = PluginClass._spyder_package_name
+                    version = PluginClass._spyder_version
+                    description = plugin_instance.get_description()
+                    dependencies.add(module, package_name, description,
+                                     version, None, kind=dependencies.PLUGIN)
                 except Exception as error:
                     print("%s: %s" % (PluginClass, str(error)), file=STDERR)
                     traceback.print_exc(file=STDERR)
@@ -981,7 +974,8 @@ class MainWindow(QMainWindow):
                                     icon=ima.icon('filelist'),
                                     tip=_('Fast switch between files'),
                                     triggered=self.open_switcher,
-                                    context=Qt.ApplicationShortcut)
+                                    context=Qt.ApplicationShortcut,
+                                    id_='file_switcher')
         self.register_shortcut(self.file_switcher_action, context="_",
                                name="File switcher")
         self.symbol_finder_action = create_action(
@@ -989,7 +983,8 @@ class MainWindow(QMainWindow):
                                     icon=ima.icon('symbol_find'),
                                     tip=_('Fast symbol search in file'),
                                     triggered=self.open_symbolfinder,
-                                    context=Qt.ApplicationShortcut)
+                                    context=Qt.ApplicationShortcut,
+                                    id_='symbol_finder')
         self.register_shortcut(self.symbol_finder_action, context="_",
                                name="symbol finder", add_shortcut_to_tip=True)
 
@@ -1052,25 +1047,20 @@ class MainWindow(QMainWindow):
             _("PYTHONPATH manager"),
             None, icon=ima.icon('pythonpath'),
             triggered=self.show_path_manager,
-            tip=_("PYTHONPATH manager"))
-        from spyder.plugins.application.plugin import (
+            tip=_("PYTHONPATH manager"),
+            id_='spyder_path_action')
+        from spyder.plugins.application.container import (
             ApplicationActions, WinUserEnvDialog)
         winenv_action = None
         if WinUserEnvDialog:
-            winenv_action = self.application.get_action(
-                ApplicationActions.SpyderWindowsEnvVariables)
+            winenv_action = ApplicationActions.SpyderWindowsEnvVariables
         mainmenu.add_item_to_application_menu(
             spyder_path_action,
             menu_id=ApplicationMenus.Tools,
             section=ToolsMenuSections.Tools,
-            before=winenv_action
+            before=winenv_action,
+            before_section=ToolsMenuSections.External
         )
-        if get_debug_level() >= 3:
-            self.menu_lsp_logs = QMenu(_("LSP logs"))
-            self.menu_lsp_logs.aboutToShow.connect(self.update_lsp_logs)
-            mainmenu.add_item_to_application_menu(
-                self.menu_lsp_logs,
-                menu_id=ApplicationMenus.Tools)
 
         # Main toolbar
         from spyder.plugins.toolbar.api import (
@@ -1113,17 +1103,6 @@ class MainWindow(QMainWindow):
             pass
         return super().__getattr__(attr)
 
-    def update_lsp_logs(self):
-        """Create an action for each lsp log file."""
-        self.menu_lsp_logs.clear()
-        lsp_logs = []
-        files = glob.glob(osp.join(get_conf_path('lsp_logs'), '*.log'))
-        for f in files:
-            action = create_action(self, f, triggered=self.editor.load)
-            action.setData(f)
-            lsp_logs.append(action)
-        add_actions(self.menu_lsp_logs, lsp_logs)
-
     def pre_visible_setup(self):
         """
         Actions to be performed before the main window is visible.
@@ -1198,9 +1177,6 @@ class MainWindow(QMainWindow):
 
         self.restore_scrollbar_position.emit()
 
-        logger.info('Deleting previous Spyder instance LSP logs...')
-        delete_lsp_log_files()
-
         # Workaround for spyder-ide/spyder#880.
         # QDockWidget objects are not painted if restored as floating
         # windows, so we must dock them before showing the mainwindow,
@@ -1259,18 +1235,6 @@ class MainWindow(QMainWindow):
         # Fixes spyder-ide/spyder#3887.
         self.menuBar().raise_()
 
-        # Handle DPI scale and window changes to show a restart message.
-        # Don't activate this functionality on macOS because it's being
-        # triggered in the wrong situations.
-        # See spyder-ide/spyder#11846
-        if not sys.platform == 'darwin':
-            window = self.window().windowHandle()
-            window.screenChanged.connect(self.handle_new_screen)
-            screen = self.window().windowHandle().screen()
-            self.current_dpi = screen.logicalDotsPerInch()
-            screen.logicalDotsPerInchChanged.connect(
-                self.show_dpi_change_message)
-
         # To avoid regressions. We shouldn't have loaded the modules
         # below at this point.
         if DEV is not None:
@@ -1281,71 +1245,6 @@ class MainWindow(QMainWindow):
         self.is_setting_up = False
         self.sig_setup_finished.emit()
 
-    def handle_new_screen(self, new_screen):
-        """Connect DPI signals for new screen."""
-        if new_screen is not None:
-            new_screen_dpi = new_screen.logicalDotsPerInch()
-            if self.current_dpi != new_screen_dpi:
-                self.show_dpi_change_message(new_screen_dpi)
-            else:
-                new_screen.logicalDotsPerInchChanged.connect(
-                    self.show_dpi_change_message)
-
-    def handle_dpi_change_response(self, result, dpi):
-        """Handle dpi change message dialog result."""
-        if self.dpi_change_dismiss_box.isChecked():
-            self.show_dpi_message = False
-            self.dpi_change_dismiss_box = None
-        if result == 0:  # Restart button was clicked
-            # Activate HDPI auto-scaling option since is needed for a
-            # proper display when using OS scaling
-            CONF.set('main', 'normal_screen_resolution', False)
-            CONF.set('main', 'high_dpi_scaling', True)
-            CONF.set('main', 'high_dpi_custom_scale_factor', False)
-            self.restart()
-        else:
-            # Update current dpi for future checks
-            self.current_dpi = dpi
-
-    def show_dpi_change_message(self, dpi):
-        """Show message to restart Spyder since the DPI scale changed."""
-        if not self.show_dpi_message:
-            return
-
-        if self.current_dpi != dpi:
-            # Check the window state to not show the message if the window
-            # is in fullscreen mode.
-            window = self.window().windowHandle()
-            if (window.windowState() == Qt.WindowFullScreen and
-                    sys.platform == 'darwin'):
-                return
-
-            self.dpi_change_dismiss_box = QCheckBox(
-                _("Hide this message during the current session"),
-                self
-            )
-
-            msgbox = QMessageBox(self)
-            msgbox.setIcon(QMessageBox.Warning)
-            msgbox.setText(
-                _
-                ("A monitor scale change was detected. <br><br>"
-                 "We recommend restarting Spyder to ensure that it's properly "
-                 "displayed. If you don't want to do that, please be sure to "
-                 "activate the option<br><br><tt>Enable auto high DPI scaling"
-                 "</tt><br><br>in <tt>Preferences > Application > "
-                 "Interface</tt>, in case Spyder is not displayed "
-                 "correctly.<br><br>"
-                 "Do you want to restart Spyder?"))
-            msgbox.addButton(_('Restart now'), QMessageBox.NoRole)
-            dismiss_button = msgbox.addButton(
-                _('Dismiss'), QMessageBox.NoRole)
-            msgbox.setCheckBox(self.dpi_change_dismiss_box)
-            msgbox.setDefaultButton(dismiss_button)
-            msgbox.finished.connect(
-                lambda result: self.handle_dpi_change_response(result, dpi))
-            msgbox.open()
-
     def set_window_title(self):
         """Set window title."""
         if DEV is not None:
@@ -1944,24 +1843,6 @@ class MainWindow(QMainWindow):
             self.sig_open_external_file.emit(fname)
             req.sendall(b' ')
 
-    # ---- Quit and restart, and reset spyder defaults
-    @Slot()
-    def reset_spyder(self):
-        """
-        Quit and reset Spyder and then Restart application.
-        """
-        answer = QMessageBox.warning(self, _("Warning"),
-             _("Spyder will restart and reset to default settings: <br><br>"
-               "Do you want to continue?"),
-             QMessageBox.Yes | QMessageBox.No)
-        if answer == QMessageBox.Yes:
-            self.restart(reset=True)
-
-    @Slot()
-    def restart(self, reset=False):
-        """Wrapper to handle plugins request to restart Spyder."""
-        self.application.restart(reset=reset)
-
     # ---- Global Switcher
     def open_switcher(self, symbol=False):
         """Open switcher dialog box."""
@@ -2055,6 +1936,8 @@ def main(options, args):
                                       CONF.get('main', 'high_dpi_scaling'))
 
     # **** Set debugging info ****
+    if get_debug_level() > 0:
+        delete_debug_log_files()
     setup_logging(options)
 
     # **** Create the application ****
